==> abstract_utilities-0.2.2.101.tar.gz: abstract_utilities-0.2.2.101/src/abstract_utilities/log_utils.py <==
import os

def mkdirs(directory: str) -> str:
    """Create the directory if it does not exist and return its path."""
    if not os.path.exists(directory):
        os.makedirs(directory)
    return directory

# Custom filter that allows or blocks records based on level booleans.
class LevelFilter(logging.Filter):
    def __init__(self, debug: bool, info: bool, warning: bool, error: bool, critical: bool):
        
        self.debug = debug
        self.info = info
        self.warning = warning
        self.error = error
        self.critical = critical

    def filter(self, record: logging.LogRecord) -> bool:
        if record.levelno == logging.DEBUG:
            return self.debug
        elif record.levelno == logging.INFO:
            return self.info
        elif record.levelno == logging.WARNING:
            return self.warning
        elif record.levelno == logging.ERROR:
            return self.error
        elif record.levelno == logging.CRITICAL:
            return self.critical
        return False

class AbstractLogManager:
    """
    A singleton log manager that configures a logger with a rotating file handler
    and an optional console handler that uses a custom level filter.
    """
    def __init__(self, name: str = "AbstractLogManager"):
        self.logger = logging.getLogger(name)
        # Clear any existing handlers on the logger so our configuration is applied fresh.
        self.logger.handlers.clear()
        self.logger.setLevel()
        self.handlers = {}
    def add_file_handler(self, bpName: str, maxBytes: int, backupCount: int) -> None:
        # Only add a file handler if one isn’t already attached.
        if not any(isinstance(h, RotatingFileHandler) for h in self.logger.handlers):
            log_dir = mkdirs("logs")
            log_path = os.path.join(log_dir, f"{bpName}.log")
            file_handler = RotatingFileHandler(log_path, maxBytes=maxBytes, backupCount=backupCount)
            file_handler.setLevel(logging.INFO)
            formatter = logging.Formatter("%(asctime)s - %(levelname)s - %(message)s")
            file_handler.setFormatter(formatter)
            self.logger.addHandler(file_handler)

    def add_console_handler(self, level_filter: LevelFilter) -> None:
        """Add a console handler with the given level filter if not already added."""
        if "console" not in self.handlers:
            console_handler = logging.StreamHandler()
            # Set the handler level low so that our custom filter controls what passes.
            console_handler.setLevel(logging.DEBUG)
            formatter = logging.Formatter("%(asctime)s - %(levelname)s - %(message)s")
            console_handler.setFormatter(formatter)
            console_handler.addFilter(level_filter)
            self.logger.addHandler(console_handler)
            self.handlers["console"] = console_handler
        else:
            # Update the filter on the existing console handler.
            self.handlers["console"].filters.clear()
            self.handlers["console"].addFilter(level_filter)

    def get_logger(self) -> logging.Logger:
        """Return the configured logger."""
        return self.logger

def get_logFile(
    bpName: str,
    maxBytes: int = 100000,
    backupCount: int = 3,
    console: bool = True,
    debug: bool = True,
    info: bool = False,
    warning: bool = False,
    error: bool = True,
    critical: bool = True
) -> logging.Logger:
    """
    Returns a logger with a rotating file handler and optional console handler,
    where the console handler is filtered by the provided booleans.

    Parameters:
      bpName (str): Base name for the logger (and used for the log filename).
      maxBytes (int): Maximum bytes before the log file rotates.
      backupCount (int): Number of backup files to keep.
      console (bool): Whether to add console logging.
      debug (bool): If True, include DEBUG messages on console.
      info (bool): If True, include INFO messages on console.
      warning (bool): If True, include WARNING messages on console.
      error (bool): If True, include ERROR messages on console.
      critical (bool): If True, include CRITICAL messages on console.
    
    Returns:
      logging.Logger: The configured logger.
    """
    # Instantiate the log manager (singleton) using bpName as the logger name.
    log_mgr = AbstractLogManager(bpName)
    
    # Always add the file handler.
    log_mgr.add_file_handler(bpName, maxBytes, backupCount)
    
    # If console logging is enabled, add a console handler with a custom filter.
    if console:
        level_filter = LevelFilter(debug=debug, info=info, warning=warning, error=error, critical=critical)
        log_mgr.add_console_handler(level_filter)
    
    return log_mgr.get_logger()
if __name__ == "__main__":
    # Create a logger for "testlogs" with the following console options:
    # Only show DEBUG messages on console (suppress INFO and WARNING)
    logger = get_logFile('testlogs', console=False, debug=False, info=False, warning=False, error=False, critical=False)
    
    logger.debug("This is a debug message.")       # Should appear if debug is enabled.
    logger.info("This is an info message.")         # Should be suppressed on console.
    logger.warning("This is a warning message.")    # Should be suppressed on console.
    logger.error("This is an error message.")       # Should appear.
    logger.critical("This is a critical message.")  # Should appear.

==> abstract_utilities-0.2.2.106.tar.gz: abstract_utilities-0.2.2.106/src/abstract_utilities/log_utils.py <==
import os
import logging
from logging.handlers import RotatingFileHandler
def mkdirs(directory: str) -> str:
    """Create the directory if it does not exist and return its path."""
    if not os.path.exists(directory):
        os.makedirs(directory)
    return directory

# Custom filter that allows or blocks records based on level booleans.
class LevelFilter(logging.Filter):
    def __init__(self, debug: bool, info: bool, warning: bool, error: bool, critical: bool):
        super().__init__()
        self.debug = debug
        self.info = info
        self.warning = warning
        self.error = error
        self.critical = critical

    def filter(self, record: logging.LogRecord) -> bool:
        if record.levelno == logging.DEBUG:
            return self.debug
        elif record.levelno == logging.INFO:
            return self.info
        elif record.levelno == logging.WARNING:
            return self.warning
        elif record.levelno == logging.ERROR:
            return self.error
        elif record.levelno == logging.CRITICAL:
            return self.critical
        return False

class AbstractLogManager:
    """
    A singleton log manager that configures a logger with a rotating file handler
    and an optional console handler that uses a custom level filter.
    """
    def __init__(self, name: str = "AbstractLogManager"):
        self.logger = logging.getLogger(name)
        # Clear any existing handlers on the logger so our configuration is applied fresh.
        self.logger.handlers.clear()
        self.logger.setLevel(logging.DEBUG)
        self.handlers = {}
    def add_file_handler(self, bpName: str, maxBytes: int, backupCount: int) -> None:
        # Only add a file handler if one isn’t already attached.
        if not any(isinstance(h, RotatingFileHandler) for h in self.logger.handlers):
            log_dir = mkdirs("logs")
            log_path = os.path.join(log_dir, f"{bpName}.log")
            file_handler = RotatingFileHandler(log_path, maxBytes=maxBytes, backupCount=backupCount)
            file_handler.setLevel(logging.INFO)
            formatter = logging.Formatter("%(asctime)s - %(levelname)s - %(message)s")
            file_handler.setFormatter(formatter)
            self.logger.addHandler(file_handler)

    def add_console_handler(self, level_filter: LevelFilter) -> None:
        """Add a console handler with the given level filter if not already added."""
        if "console" not in self.handlers:
            console_handler = logging.StreamHandler()
            # Set the handler level low so that our custom filter controls what passes.
            console_handler.setLevel(logging.DEBUG)
            formatter = logging.Formatter("%(asctime)s - %(levelname)s - %(message)s")
            console_handler.setFormatter(formatter)
            console_handler.addFilter(level_filter)
            self.logger.addHandler(console_handler)
            self.handlers["console"] = console_handler
        else:
            # Update the filter on the existing console handler.
            self.handlers["console"].filters.clear()
            self.handlers["console"].addFilter(level_filter)

    def get_logger(self) -> logging.Logger:
        """Return the configured logger."""
        return self.logger

def get_logFile(
    bpName: str,
    maxBytes: int = 100000,
    backupCount: int = 3,
    console: bool = True,
    debug: bool = True,
    info: bool = False,
    warning: bool = False,
    error: bool = True,
    critical: bool = True
) -> logging.Logger:
    """
    Returns a logger with a rotating file handler and optional console handler,
    where the console handler is filtered by the provided booleans.

    Parameters:
      bpName (str): Base name for the logger (and used for the log filename).
      maxBytes (int): Maximum bytes before the log file rotates.
      backupCount (int): Number of backup files to keep.
      console (bool): Whether to add console logging.
      debug (bool): If True, include DEBUG messages on console.
      info (bool): If True, include INFO messages on console.
      warning (bool): If True, include WARNING messages on console.
      error (bool): If True, include ERROR messages on console.
      critical (bool): If True, include CRITICAL messages on console.
    
    Returns:
      logging.Logger: The configured logger.
    """
    # Instantiate the log manager (singleton) using bpName as the logger name.
    log_mgr = AbstractLogManager(bpName)
    
    # Always add the file handler.
    log_mgr.add_file_handler(bpName, maxBytes, backupCount)
    
    # If console logging is enabled, add a console handler with a custom filter.
    if console:
        level_filter = LevelFilter(debug=debug, info=info, warning=warning, error=error, critical=critical)
        log_mgr.add_console_handler(level_filter)
    
    return log_mgr.get_logger()
